import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { Info } from '@ucap-webmessenger/protocol-event';
import { NGXLogger } from 'ngx-logger';
import { StatusCode } from '@ucap-webmessenger/api';
import { MassTextInfo } from '../../models/mass-talk-info.json';
import { StringUtil } from '@ucap-webmessenger/ui';

@Component({
  selector: 'ucap-chat-message-box-mass',
  templateUrl: './mass.component.html',
  styleUrls: ['./mass.component.scss']
})
export class MassComponent implements OnInit {
  @Input()
  message: Info;

  @Output()
  massDetail = new EventEmitter<number>();

  content: string;
  eventMassSeq: number;
  detailButteonShow = true;

  constructor(private logger: NGXLogger) {}

  ngOnInit() {
    try {
      const contentJson: MassTextInfo = StringUtil.receiveAnalization(
        this.message.sentMessage
      );
      if (contentJson.StatusCode === StatusCode.Success) {
        this.content = contentJson.Content;
      } else {
        this.content = contentJson.ErrorMessage || '[Error] System Error!!';
        this.detailButteonShow = false;
      }

      if (!!contentJson.EventMassSeq) {
        this.eventMassSeq = contentJson.EventMassSeq;
      } else {
        this.detailButteonShow = false;
      }
    } catch (e) {
      this.logger.error(e);
      this.detailButteonShow = false;
    }
  }

  onClickDetailView() {
    this.massDetail.emit(this.eventMassSeq);
  }
}
